pub struct ImportGroup {
pub first_line: usize,
pub last_line: usize,
pub kind: ImportKind,
}Expand description
A contiguous block of module-level import lines (separated from other blocks by blank lines or comment lines), with a classification for the whole group.
Fields
first_line: usize0-based index of the first line in this group.
last_line: usize0-based index of the last line in this group (inclusive).
kind: ImportKindClassification based on the first import in the group.