pub struct ParamInsertionInfo {
pub line: usize,
pub char_pos: usize,
pub needs_comma: bool,
}Expand description
Information about where to insert a new parameter in a function signature.
Fields
line: usizeLine number (1-indexed) where the function signature is.
char_pos: usizeCharacter position where the new parameter should be inserted.
needs_comma: boolWhether a comma needs to be added before the new parameter.