Data structures for fixture definitions, usages, and related types.
Structs
- Fixture
Cycle - A circular dependency between fixtures.
- Fixture
Definition - A fixture definition extracted from a Python file.
- Fixture
Usage - A fixture usage (reference) in a Python file.
- Param
Insertion Info - Information about where to insert a new parameter in a function signature.
- Scope
Mismatch - A scope mismatch where a broader-scoped fixture depends on a narrower-scoped fixture.
- Undeclared
Fixture - An undeclared fixture used in a function body without being declared as a parameter.
Enums
- Completion
Context - Context for code completion.
- Fixture
Scope - Pytest fixture scope, ordered from narrowest to broadest. A fixture with a broader scope cannot depend on a fixture with a narrower scope.